#
# spec file for package syntax-highlighting
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang
%define lname   libKF5SyntaxHighlighting5
%define _tar_path 5.45
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %global _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           syntax-highlighting
Version:        5.45.0
Release:        lp150.1.13
Summary:        Syntax highlighting engine and library
License:        LGPL-2.1-or-later AND GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-only AND MIT AND BSD-3-Clause AND Artistic-1.0
Group:          System/GUI/KDE
Url:            http://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
%if %{with lang}
BuildRequires:  cmake(Qt5LinguistTools) >= 5.6.0
%endif
BuildRequires:  cmake(Qt5Core) >= 5.6.0
BuildRequires:  cmake(Qt5Gui) >= 5.6.0
BuildRequires:  cmake(Qt5Network) >= 5.6.0
BuildRequires:  cmake(Qt5Test) >= 5.6.0
BuildRequires:  cmake(Qt5Widgets) >= 5.6.0
BuildRequires:  cmake(Qt5XmlPatterns) >= 5.6.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is a tier1/functional version of the Kate syntax highlighting engine.
It's not tied to a particular output format or editor engine.

%package -n %{lname}
Summary:        Syntax highlighting engine and library
Group:          System/GUI/KDE
Recommends:     %{name} = %{version}
%if %{with lang}
Recommends:     %{lname}-lang = %{version}
%endif

%description -n %{lname}
This is a tier1/functional version of the Kate syntax highlighting engine.
It's not tied to a particular output format or editor engine.

%package devel
Summary:        Syntax highlighting engine and library
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       extra-cmake-modules
Requires:       cmake(Qt5Core) >= 5.6.0
Requires:       cmake(Qt5Gui) >= 5.6.0

%description devel
This is a tier1/functional version of the Kate syntax highlighting engine.
It's not tied to a particular output format or editor engine.

%lang_package -n %lname
%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang syntaxhighlighting5 --with-qt --without-mo
%endif

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%if %{with lang}
%files -n %lname-lang -f syntaxhighlighting5.lang
%endif

%files
%defattr(-,root,root)
%doc COPYING* README*
%config %{_kf5_configdir}/org_kde_ksyntaxhighlighting.categories
%{_kf5_bindir}/kate-syntax-highlighter

%files -n %{lname}
%defattr(-,root,root)
%doc COPYING* README*
%{_kf5_libdir}/libKF5SyntaxHighlighting.so.*

%files devel
%defattr(-,root,root)
%{_kf5_libdir}/libKF5SyntaxHighlighting.so
%{_kf5_libdir}/cmake/KF5SyntaxHighlighting/
%{_kf5_mkspecsdir}/qt_KSyntaxHighlighting.pri
%{_kf5_includedir}/

%changelog
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Fix CMake highlighting tests
  * Make it possible to fully build the project when crosscompiling
  * Redesign CMake syntax generator
  * Optimize highlighting Bash, Cisco, Clipper, Coffee, Gap, Haml, Haskell
  * Remove not necessary QtCore and co
  * Add syntax highlighting for MIB files
* Tue Mar 13 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Basic support for PHP and Python fenced code blocks in Markdown
  * Support case-insensitive WordDetect
  * Scheme highlighting: Remove hard-coded colors
  * Add syntax highlighting for SELinux CIL Policies & File Contexts
  * Adding ctp file extension to the PHP syntax highlighting
  * Yacc/Bison: Fix the $ symbol and update syntax for Bison
  * awk.xml: add gawk extension keywords (kde#389590)
  * Add APKBUILD to be highlighted as a Bash file
  * Revert "Add APKBUILD to be highlighted as a Bash file"
  * Add APKBUILD to be highlighted as a Bash file
* Tue Feb 13 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix C# var regex
  * Support for underscores in numeric literals (Python 3.6) (kde#385422)
  * AppArmor: Fix style
  * Highlight Khronos Collada and glTF files
  * Fix ini highlighting of values containing ; or # characters
  * AppArmor: new keywords, improvements & fixes
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Too many changes to list here
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Add PKGUILD to bash syntax
  * JavaScript: include standard mime types
  * debchangelog: add Bionic Beaver
  * Update SQL (Oracle) syntax file (kde#386221)
  * SQL: move detecting comments before operators
  * crk.xml: added <?xml> header line
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Makefile: fix regexpr matching in "CXXFLAGS+"
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Fix non-existing itemDatas
  * Fix invalid itemData references of 57 highlighting files
  * Add support for custom search paths for application-specific syntax and theme definitions
  * remove extra executable bits
  * AppArmor: fix DBus rules
  * Highlighting indexer: factor out checks for smaller while loop
  * ContextChecker: support '!' context switchting and fallthroughContext
  * Highlighting indexer: check existence of referenced context names
  * remove extra executable bits
  * Relicense qmake highlighting to MIT license
  * Let qmake highlighting win over Prolog for .pro files (kde#383349)
  * Support clojure's "@" macro with brackets
  * Add syntax highlighting for AppArmor Profiles.
  * Highlighting indexer: Catch invalid a-Z/A-z ranges in regexps
  * Fixing incorrectly capitalized ranges in regexps
  * add missing reference files for tests, looks ok, I think
  * Added Intel HEX file support for the Syntax highlighting database
  * Disable spell checking for strings in Sieve scripts
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Add syntax definition for Adblock Plus filter lists
  * Rewrite the Sieve syntax definition
  * Add highlighting for QDoc configuration files
  * Add highlight definition for Tiger
  * Escape hyphen in rest.xml regular expressions (kde#383632)
  * fix: plaintext is highlighted as powershell
  * indexer: Use qWarning for every error message
  * Add syntax highlighting for Metamath
  * Lesscss highlighting: Add generated reference as unit test
  * Rebased Less syntax highlighting on SCSS one (kde#369277)
  * Add Pony highlighting
  * Rewrite the email syntax definition
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Allow to build KSyntaxHighlighter without Qt5Gui
  * Add cross-compilation support for the highlighting indexer
  * Themes: Remove all unused metadata (license, author, read-only)
  * Theme: Remove license and author fields
  * Theme: Derive read-only flag from file on disk
  * Add syntax highlighting for YANG data modeling language
  * PHP: Add PHP 7 keywords (kde#356383)
  * PHP: Clean up PHP 5 information
  * fix gnuplot, make leading/trailing spaces fatal
  * fix 'else if' detection, we need to switch context, add extra rule
  * indexer checks for leading/trailing whitespaces in XML highlighting
  * Doxygen: Add Doxyfile highlighting
  * add missing standard types to C highlighting and update to C11 (kde#367798)
  * Q_PI D => Q_PID
  * PHP: Improve highlighting of variables in curly braces in double quotes (kde#382527)
  * Add PowerShell highlighting
  * Haskell: Add file extension .hs-boot (bootstrap module) (kde#354629)
  * Fix replaceCaptures() to work with more than 9 captures
  * Ruby: Use WordDetect instead of StringDetect for full word matching
  * Fix incorrect highlighting for BEGIN and END in words such as "EXTENDED" (kde#350709)
  * PHP: Remove mime_content_type() from list of deprecated functions (kde#371973)
  * XML: Add XBEL extension/mimetype to xml highlighting (kde#374573)
  * Bash: Fix incorrect highlighting for command options (kde#375245)
  * Perl: Fix heredoc highlighting with leading spaces in the delimiter (kde#379298)
  * Update SQL (Oracle) syntax file (kde#368755)
  * C++: Fix '-' is not a part of UDL String (kde#380408)
  * C++: printf format specifies: add 'n' and 'p', remove 'P' (kde#380409)
  * C++: Fix char value have the color of the strings (kde#380489)
  * VHDL: Fix highlighting error when using brackets and attributes (kde#368897)
  * zsh highlighting: Fix math expression in a substring expression (kde#380229)
  * JavaScript Highlighting: Add support for E4X xml extension (kde#373713)
  * Remove "*.conf" extension rule
  * Pug/Jade syntax
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Highlight .julius files as JavsScript.
  * Haskell: Add all language pragmas as keywords.
  * add unit test for isocpp
  * CMake: Fix CMP0058 warning when using Ninja
  * Don't assume 'diff' is in PATH for other tests
  * testhighlighter: Don't assume 'diff' is in PATH
  * Makefile: increase version number
  * CMake: OR/AND not highlighted after expr in () (kde#360656)
  * Makefile: Remove invalid keyword entries in makefile.xml
  * indexer: Improve error reporting
  * Add since tags.
  * HTML syntax file version update
  * Angular modifiers in HTML attributes added
  * [FEATURE] Option to build & install QCH file with the public API dox
  * Update test reference data following the changes of the previous commit
  * Bug 376979 - angle brackets in doxygen comments break syntax highlighting
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Haskell: highlight "julius" quasiquoter using Normal##Javascript rules.
  * Haskell: enable hamlet highlighting for "shamlet" quasiquoter too.
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Add Arduino extension
  * debchangelog: add Ubuntu Artful
  * Adapt test reference data to changes in the input data
  * LaTeX: Fix Incorrect termination of \iffalse comments (kde#378487)
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * TOML: Fix highlighting of string escape sequences
  * Update Clojure syntax highlighting
  * few updates to OCaml syntax
  * Hightlight *.sbt files as scala code
  * Also use the QML highlighter for .qmltypes files
  * Add unit test for Apache configuration highlighting
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Fix autotest
  * Add more keyword. Disable spellchecking for keywords
  * Fix typo
  * Add more keyword
  * Add *.RHTML file extension to Ruby on Rails highlighting
  * Update SCSS and CSS syntax highlight
  * less highlighting: Fix single line comments starting new regions
  * Upgrade KF5 version to 5.32.0.
  * LaTeX highlighting: fix alignat environment
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Normalize XML license attribute values
  * Sync syntax definitions from ktexteditor
  * Fix folding region merging
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Wed Nov 30 2016 lbeltrame@kde.org
- Adjust licenses as pointed out by legal review
* Mon Sep 19 2016 lbeltrame@kde.org
- Initial version of the package.
